@@ -1,14 +1,15 @@
 package Path::Hilbert;
 
+use strict;
+use warnings;
 use 5.012;
-
-use local::lib;
+use utf8;
 
 use Exporter qw( import );
 
 our @EXPORT = qw( xy2d d2xy );
 
-our $VERSION = 1.202;
+our $VERSION = '1.203';
 
 # optional constructor if you want OO-style
 sub new {
