@@ -1,8 +1,9 @@
 package Path::Hilbert::BigInt;
 
+use strict;
+use warnings;
 use 5.012;
-
-use local::lib;
+use utf8;
 
 use Math::BigRat try => 'GMP,Pari,Calc';
 use Math::BigInt try => 'GMP,Pari,Calc';
@@ -11,7 +12,7 @@ use Exporter qw( import );
 
 our @EXPORT = qw( xy2d d2xy );
 
-our $VERSION = 1.202;
+our $VERSION = '1.203';
 
 # optional constructor if you want OO-style
 sub new {
